@@ -70,4 +70,7 @@ class sdk:
         return _dokumenter.dokumenter(self, folderid)
 
     def forside(self):
-        return _forside.forside(self)
\ No newline at end of file
+        return _forside.forside(self)
+
+    def besvarBesked(self, message_id, id, titel, content, _from=0):
+        return _beskeder.besvarBesked(self, message_id, id, titel, content, _from)
\ No newline at end of file
